Distilles the most relevant data from an output object of t.test and displays the results in a compact format.
t_out(toutput, n.equal = TRUE,
welch.df.exact = TRUE, welch.n = NA,
d.corr = TRUE, print = TRUE)Output object created by a call to t.test.
Only applicable to two-sample t-tests. If sample sizes are not equal, n.equal specifies a vector of sample sizes, e.g., n.equal = c(12,8).
Only applicable to Welch-tests. Indicates whether Welch-adjusted or unadjusted degrees of freedom (dfs) are reported (default=TRUE, i.e., Welch-adjusted dfs). If set to FALSE, the parameter welch.n has to be set as well.
Only applicable to Welch-tests with unadjusted degrees of freedom. Parameter should be equal to the total sample size n=n_1+n_2.
Only applicable to one-sample or paired-samples t-tests. If TRUE (default), Cohen's ds are computed using sqrt(2)-correction.
Force results to be displayed, even if the function output is assigned to a variable (e.g., output <- t_out(...); logical; default=TRUE).
t_out(toutput,...) returns a list containing (1) a description of the t-test (two-sample t-test, Welch-test, paired-samples t-test, one-sample t-test) and (2) a line with formatted results.
The output of a call to t_out is formatted according to the guidelines of the APA (American Psychological Association) as well as the DGPs ("Deutsche Gesellschaft fuer Psychologie"; German Psychological Society).